<?php

$st_cache_settings = [];

function st_get_option($name) {
	global $modx;
	global $st_cache_settings;
	if(isset($st_cache_settings[$name])) {
		return $st_cache_settings[$name];
	}
	else {
		$value = $modx->getOption($name);
		$st_cache_settings[$name] = $value;
		return $value;
	}
}

function st_set_option($name, $value) {
	global $modx;
	global $st_cache_settings;
	$setting = $modx->getObject('modSystemSetting', $name);
//var_dump("st_set_option($name, $value)", $setting);
	if(!$setting) {
		$setting = $modx->newObject('modSystemSetting');
		$setting->set('key', $name);
		$setting->set('value', $value);
		$setting->set('xtype', 'textfield');
		$setting->set('namespace', 'subtotal');
		$setting->set('area', 'subtotal');
		$setting->save();
	}
	else {
		$setting->set('value', $value);
		$setting->save();
	}
	$st_cache_settings[$name] = $value;
}

function st_reset_cache() {
    global $modx;
    // Reset cache
    $cacheRefreshOptions =  [
        'system_settings' => [],
        'resource' => [],
    ];
    $modx->cacheManager->refresh($cacheRefreshOptions);
}

function st_get_product_by_name($title) {
	global $modx;
	// https://docs.modx.pro/komponentyi/minishop2/interfejs/tovar
	$products = $modx->getIterator('msProduct', array('class_key' => 'msProduct'));
	foreach ($products as $product) {
		$current_product_title = $product->get("pagetitle");
		if($current_product_title == $title) {
			return $product;
		}
	}
	return null;
}

function st_get_product_by_id($id) {
	global $modx;
	return $modx->getObject('msProduct', $id);
}

function st_get_groups_list() {
	global $modx;

	$result = [];

	$categories = $modx->getIterator('msCategory', array('class_key' => 'msCategory'));
	foreach($categories as $category) {
		$name = $category->get("pagetitle");
		$id = $category->get("id");
		$result[$id] = $name;
	}

	return $result;
}

function st_get_templates_list() {
	global $modx, $table_prefix;

	$result = [];

	$templates = $modx->query("SELECT `id`, `templatename` FROM `${table_prefix}site_templates`");
	if (is_object($templates)) {
	while($template = $templates->fetch(PDO::FETCH_ASSOC)) {
		$name = $template["templatename"];
		$id = $template["id"];
		$result[$id] = $name;
	}
	}
	return $result;
}

function st_set_ids_link($modx_id, $subtotal_id) {
	global $modx, $table_prefix;

	$exists_modx_id = st_get_modx_id_by_subtotal_id($subtotal_id);
	$param_name = "good_$subtotal_id";

	if($exists_modx_id == $modx_id) return;

	$query_delete = "DELETE FROM `${table_prefix}subtotal_items` WHERE `name` = :param_name";
	$res = $modx->prepare($query_delete);
	$res->bindParam(":param_name", $param_name, PDO::PARAM_STR);
	$res->execute();

	$query_insert = "INSERT INTO `${table_prefix}subtotal_items` (`name`, `description`) VALUES (:param_name, :value)";
	$res = $modx->prepare($query_insert);
	$res->bindParam(":param_name", $param_name, PDO::PARAM_STR);
	$res->bindParam(":value", $modx_id, PDO::PARAM_STR);
	$res->execute();
}

function st_get_subtotal_id_by_modx_id($modx_id) {
	global $modx, $table_prefix;
	$query_select = "SELECT `name` FROM `${table_prefix}subtotal_items` WHERE `name` LIKE 'good_%' AND `description` = :modx_id";
	$res = $modx->prepare($query_select);
	$res->bindParam(":modx_id", $modx_id, PDO::PARAM_STR);
	$res->execute();
	$data = $res->fetch(PDO::FETCH_ASSOC);
	$result = $data['name'];
	if(preg_match('/^good_([0-9]+)$/', $result, $matches)) {
		return $matches[1];
	}
	return null;
}

function st_get_modx_id_by_subtotal_id($subtotal_id) {
	global $modx, $table_prefix;
	$param_name = "good_$subtotal_id";
	$query_select = "SELECT `description` FROM `${table_prefix}subtotal_items` WHERE `name` = :param_name";
	$res = $modx->prepare($query_select);
	$res->bindParam(":param_name", $param_name, PDO::PARAM_STR);
	$res->execute();
	$data = $res->fetch(PDO::FETCH_ASSOC);
	$modx_id = intval($data['description']);
//st_log("st_get_modx_id_by_subtotal_id($subtotal_id) = $modx_id");
	return $modx_id;
}

function get_subtotal_sale_id_by_modx_sale_id($modx_id) {
	global $modx, $table_prefix;
	$param_name = "sale_$modx_id";
	$query_select = "SELECT `description` FROM `${table_prefix}subtotal_items` WHERE `name` = :param_name";
	$res = $modx->prepare($query_select);
	$res->bindParam(":param_name", $param_name, PDO::PARAM_STR);
	$res->execute();
	$data = $res->fetch(PDO::FETCH_ASSOC);
	$subtotal_id = intval($data['description']);
	return $subtotal_id;
}

function set_subtotal_sale_id_by_modx_sale_id($modx_id, $subtotal_sale_id) {
	global $modx, $table_prefix;
	$param_name = "sale_$modx_id";
	$exists_subtotal_sale_id = get_subtotal_sale_id_by_modx_sale_id($modx_id);
	if($exists_subtotal_sale_id == $subtotal_sale_id) return;

	$query_insert = "INSERT INTO `${table_prefix}subtotal_items` (`name`, `description`) VALUES (:param_name, :value)";
	$res = $modx->prepare($query_insert);
	$res->bindParam(":param_name", $param_name, PDO::PARAM_STR);
	$res->bindParam(":value", $subtotal_sale_id, PDO::PARAM_STR);
	$res->execute();
}

function st_set_tv_value($good, $name, $value) {
	if($good->setTVValue($name, $value)) {
		return true;
	}
	else {
		return false;
	}
}

function st_get_tv_value($good, $name) {
	return $good->getTVValue($name);
}

function st_create_tv_variables() {
	global $modx;

	$names_array = [
		"stock" => "Остаток",
		"unit" => "Единица измерения",
		"weight" => "Вес",
		"subtotal_id" => "Subtotal ID",
		"country" => "Страна",
		"barcode" => "Штрих-код",
	];
	foreach($names_array as $name => $desc) {
		if (!$tv = $modx->getObject('modTemplateVar', array('name' => $name))) {
			$tv = $modx->newObject('modTemplateVar');
			$tv->fromArray(array(
				"name" => $name,
				"type" => "text",
				"caption" => $desc,
				"desription" => $desc,
				"category" => 0,
			));
			$tv->save();
		}
		$tv = $modx->getObject('modTemplateVar', array('name' => $name));
		$tv_id = $tv->get('id');
		$tvt = $modx->newObject('modTemplateVarTemplate');
		$tvt->set('tmplvarid', $tv_id);
		$template_id = st_get_import_to_template();
		if($template_id) {
			//echo "Set template_id $template_id to $tv_id\n";
			$tvt->set('templateid', $template_id);
			$tvt->save();
		}
	}
}
