<?php
/**
 * Процедуры, осуществляющие подготовку к запуску процедур импорта из разных контекстов
 */

/**
 * Процедура импорта по расписанию
 * 
 * Устанавливает всякие переменные состояния и запускает импорт
 * 
 * Используется в хуке subtotal_cron_hook
 */
function subtotal_cron_exec() {
	global $wpdb;

	// Время последней синхронизации
	$prev_activity_timestamp = st_get_last_sync_action_timestamp();
	if($prev_activity_timestamp == 0) {
		echo "No auto sync before manual sync\n";
		return;
	}

	$interval_sec = time() - $prev_activity_timestamp;
	$interval_min = $interval_sec / 60;

	$update_period = st_get_update_period();

	if($interval_min < $update_period) {
		echo "Not a time for auto sync yet: $interval_min < $update_period\n";
		return;
	}

	// Обновляем время последней активности по синхронизации
	st_set_last_sync_action_timestamp(time());

	// Отмена ограничений по памяти
	ini_set("memory_limit",-1);

	// Отмена ограничений времени выполнения, игнорирование сброса
	set_time_limit(0);
	ignore_user_abort(true);

	// Текущие настройки Subtotal
	$pos_id = st_get_stock_store();
	$price_id = st_get_import_price();
	$page_size = st_get_import_limit_value();

	// Получение склада, привязанного к выбранному магазину
	$poses = st_getPoses();
	$store_id = '';
	foreach($poses['poses'] as $pos_data) {
		if($pos_id == $pos_data['id']) {
			$store_id = $pos_data['store_id'];
			break;
		}
	}
	if(!$store_id) {
		echo "Error: store_id not found\n";
		return;
	}

	// Получаем и обновляем параметр времени последней синхронизации
	$prev_import_timestamp = st_get_prev_import_timestamp();
	st_set_prev_import_timestamp(time());
	echo "Syncing changes from ".date("d.m.Y H:i:s", $prev_import_timestamp)."\n";

	$page_num = 1;
	do {
		$catalog = st_getStoreGoods($store_id, $price_id, $page_num, $page_size, $prev_import_timestamp);
		st_log(["function" => "subtotal_cron_exec",
			"prev_import_timestamp" => $prev_import_timestamp,
			"page_num" => "$page_num",
			"catalog" => $catalog]);
		$ids = count($catalog['goods']);
		echo "Syncing page $page_num ($ids goods)\n"; flush();

		foreach($catalog['goods'] as $product) {
			st_insertOrUpdateProduct($product, true);
		}

		if($ids == 0) $done_flag = 1;
		else $done_flag = 0;
		$page_num ++;

		// Обновляем время последней активности по синхронизации
		st_set_last_sync_action_timestamp(time());
		st_reset_cache();
	} while(!$done_flag);

	echo "Syncing done\n";
	// Обновляем время последней активности по синхронизации
	st_set_last_sync_action_timestamp(time());
	st_reset_cache();
}

/**
 * Процедура импорта по нажатию кнопки
 */
function st_importProducts($page_num) {
	ini_set("memory_limit",-1);
	set_time_limit(0);
	ignore_user_abort(true);

	$pos_id = st_get_stock_store();
	$price_id = st_get_import_price();
	$page_size = st_get_import_limit_value();

	$poses = st_getPoses();
	$store_id = '';
	foreach($poses['poses'] as $pos_data) {
		if($pos_id == $pos_data['id']) {
			$store_id = $pos_data['store_id'];
			break;
		}
	}
	if(!$store_id) return;

	$catalog = st_getStoreGoods($store_id, $price_id, $page_num, $page_size);
	st_log(["function" => "st_importProducts($page_num)", "catalog" => $catalog]);

	$ids = 0;
	$ids = count($catalog['goods']);

	foreach($catalog['goods'] as $product) {
		st_set_last_sync_action_timestamp(time());
		st_insertOrUpdateProduct($product, false);
	}

	if(count($catalog['goods']) == 0) $done_flag = 1;
	else $done_flag = 0;

	return ["result" => "ok", "count" => $ids, "done" => $done_flag, ];
}

